@@ -161,7 +161,7 @@ class SurfingEntrance(object):
 
         print('to check raw data downloader')
         from .data.fund.raw.raw_data_downloader import RawDataDownloader
-        # can not construct an object of RawDataDownloader
+        _ = RawDataDownloader(dry_run=True)
         print('check raw data downloader done')
 
         print('to check basic data downloader')
