@@ -1492,12 +1492,14 @@ class BasicDataApi(metaclass=Singleton):
             df_result = df_result / df_result.iloc[0]
             df_result_show = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['show_name'])
             df_result_real = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['real_name'])
+            df_result_show.index.name = 'datetime'
+            df_result_real.index.name = 'datetime'
             asset_info = asset_info.drop_duplicates(subset=['real_id'])
             dic = {'data':df_result_show,'_input_asset_nav':df_result_real,'_input_asset_info':asset_info}
             return dic
         
         except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.get_asset_price')
+            print(f'failed to asset price <err_msg> {e} from basic.get_asset_price')
 
     def get_product_price(self, begin_date, end_date, time_para, product_list: Tuple[str] = (),):
         try:
@@ -1529,7 +1531,7 @@ class BasicDataApi(metaclass=Singleton):
             return dic
         
         except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.get_product_price')
+            print(f'failed to asset price <err_msg> {e} from basic.get_product_price')
 
     def product_recent_rate(self, product_list, year:int=None):
         try:
@@ -1575,7 +1577,7 @@ class BasicDataApi(metaclass=Singleton):
             index_ret.index.name = 'index_id'
             return index_ret
         except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.get_product_recent_price')
+            print(f'failed to asset price <err_msg> {e} from basic.get_product_recent_price')
 
     def data_resample_monthly_nav(self, df, rule='1M'):
         df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).last()
@@ -1642,6 +1644,15 @@ class BasicDataApi(metaclass=Singleton):
             index_price = pd.concat(result,axis=1).sort_index().ffill().dropna().rename(columns=name_dic)
             if year is None:
                 # 年度
+                ## 年度收益净值调整
+                b_d = index_price.index.values[0]
+                if b_d < datetime.date(b_d.year,12,1):
+                    _b_d = datetime.date(b_d.year-1,12,31)
+                    index_price.loc[_b_d] = index_price.iloc[0]
+                    index_price = index_price.sort_index()
+                else:
+                    _b_d = index_price.loc[:datetime.date(b_d.year,12,31)].index[0]
+                    index_price = index_price.loc[_b_d:].copy()
                 index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
                 index_ret_year = index_price_y.pct_change(1).dropna()
                 td = index_ret_year.index
@@ -1663,7 +1674,7 @@ class BasicDataApi(metaclass=Singleton):
             return index_ret
 
         except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.asset_recent_rate')
+            print(f'failed to asset price <err_msg> {e} from basic.asset_recent_rate')
             
     def market_size_df(self,begin_date, end_date, time_para, codes=['cninfo_smallcap','cni_largec','cni_midcap']):
         try:
@@ -1678,7 +1689,7 @@ class BasicDataApi(metaclass=Singleton):
             return index_price
 
         except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.market_size_df')
+            print(f'failed to asset price <err_msg> {e} from basic.market_size_df')
 
     def get_main_index_future_diff_yearly(self, begin_date, end_date, time_para, codes=['EMM00597141','EMM00597142','EMM00597143']):
         try:
@@ -1733,7 +1744,7 @@ class BasicDataApi(metaclass=Singleton):
             return df
 
         except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.get_main_index_future_diff_yearly')
+            print(f'failed to asset price <err_msg> {e} from basic.get_main_index_future_diff_yearly')
     
     def get_industry_list(self):
         try:
@@ -1752,7 +1763,7 @@ class BasicDataApi(metaclass=Singleton):
             df_info = self.get_index_info(industry_list)
             info_dic = {r.index_id : r.desc_name.replace('(申万)','') for r in df_info.itertuples()}
             df = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=industry_list)
-            df = df.pivot_table(columns='index_id',values='close',index='datetime')
+            df = df.pivot_table(columns='index_id',values='close',index='datetime').dropna()
             df = df / df.iloc[0]
             df = df.rename(columns=info_dic)
             return df
@@ -1786,4 +1797,4 @@ class BasicDataApi(metaclass=Singleton):
             index_ret = index_ret.rename(columns=desc_name_dic)
             return index_ret.T
         except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.get_industry_recent_ret')
\ No newline at end of file
+            print(f'failed to asset price <err_msg> {e} from basic.get_industry_recent_ret')
\ No newline at end of file
