@@ -619,6 +619,35 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_nav_public <err_msg> {e} from {FOFNavPublic.__tablename__}')
 
+    def get_fof_nav_calc(self, fof_id_list: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    FOFNavCalc,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFNavCalc.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_nav_calc <err_msg> {e} from {FOFNavCalc.__tablename__}')
+
+    def delete_fof_nav_calc(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFNavCalc
+                ).filter(
+                    FOFNavCalc.fof_id.in_(fof_id_list),
+                    FOFNavCalc.datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFNavCalc.__tablename__}')
+                return False
+
     def get_fof_position(self, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
@@ -774,12 +803,8 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {HedgeFundInvestorDivAndCarry.__tablename__}')
                 return False
 
-    def get_style_factor_ret(self, begin_date, end_date, index_list=['hs300']):
+    def get_style_factor_ret(self, begin_date, end_date, time_para, index_list=['hs300']):
         try:
-            if begin_date is None or end_date is None:
-                time_para = 'YTD'
-            else:
-                time_para = None
             start_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
             df = self.get_style_factor_return(start_date, end_date, [index_list])
             dic = {
