@@ -353,7 +353,7 @@ class OverseaFundNavAnalysis:
         failed_tasks.extend(self.process_recent_ret())
         return failed_tasks
 
-    def monthly_prcess(self, end_date):
+    def weekly_process(self, end_date):
         self.init(end_date)
         failed_tasks = []
         failed_tasks.extend(self.process_indicators())
