@@ -1,6 +1,7 @@
 
 import traceback
 import pandas as pd
+import datetime
 # from .rq_raw_data_downloader import RqRawDataDownloader
 from .em_raw_data_downloader import EmRawDataDownloader
 from .web_raw_data_downloader import WebRawDataDownloader
@@ -11,11 +12,11 @@ from ...api.raw import RawDataApi
 
 
 class RawDataDownloader:
-    def __init__(self, rq_license=None):
+    def __init__(self, rq_license=None, dry_run=False):
         self._data_helper = RawDataHelper()
         # self.rq_downloader = RqRawDataDownloader(rq_license, self._data_helper)
         self.web_downloader = WebRawDataDownloader(self._data_helper)
-        self.em_downloader = EmRawDataDownloader(self._data_helper)
+        self.em_downloader = EmRawDataDownloader(self._data_helper, dry_run)
         self.oversea_download = OverseaDataUpdate(update_period=10, data_per_page=5, data_helper=self._data_helper)
         self.oversea_download_long_term = OverseaDataUpdate(update_period=400, data_per_page=600, data_helper=self._data_helper)
         self.other_raw_data_downloader = OtherRawDataDownloader(data_helper=self._data_helper)
@@ -66,9 +67,9 @@ class RawDataDownloader:
                 print(f'got next trading day {next_trading_day}')
                 next_trading_dt = pd.to_datetime(next_trading_day, infer_datetime_format=True).date()
                 end_date_dt = pd.to_datetime(end_date, infer_datetime_format=True).date()
-                if end_date_dt.year == next_trading_dt.year and end_date_dt.month == next_trading_dt.month:
-                    # 表明本月后边还有交易日，今天不需要更新
-                    print(f'monthly indicator only update on the last day of month, not today {end_date_dt}')
+                if end_date_dt.weekday() < next_trading_dt.weekday() and next_trading_dt < end_date_dt + datetime.timedelta(weeks=1):
+                    # 表明本非周末，今天不需要更新
+                    print(f'monthly indicator update on every weekend, not today {end_date_dt}')
                 else:
                     failed_tasks.extend(self.oversea_download_long_term.update_fund_adj_factor())
                     failed_tasks.extend(self.other_raw_data_downloader.fund_nav_adj_process())
