@@ -310,8 +310,10 @@ class HedgeFundNAVReader:
             if df.empty:
                 return
             df['insert_time'] = df.insert_time.map(lambda x: x.to_pydatetime())
+            df = df.set_index(['fund_id', 'datetime'])
             print(df)
-            df.update(now_df, overwrite=False)
+            df.update(now_df.set_index(['fund_id', 'datetime']), overwrite=False)
+            df = df.reset_index()
             print(df)
             # 先删后添
             for fund_id in df.fund_id.unique():
