@@ -729,6 +729,21 @@ class FOFNavPublic(FOFBase):
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
 
 
+class FOFNavCalc(FOFBase):
+    '''fof净值数据表(计算)'''
+
+    __tablename__ = 'fof_nav_calc'
+
+    fof_id = Column(CHAR(16), primary_key=True)             # 产品ID
+    datetime = Column(DATE, primary_key=True)               # 日期
+    nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
+    acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
+    adjusted_nav = Column(DOUBLE(asdecimal=False))          # 复权净值
+    volume = Column(DOUBLE(asdecimal=False))                # 份额
+    mv = Column(DOUBLE(asdecimal=False))                    # 市值
+    ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
+
+
 class FOFPosition(FOFBase):
     '''fof持仓汇总数据'''
 
