@@ -28,8 +28,10 @@ class SeriesStatUnit:
     trade_year: float                   # 交易年限
     last_unit_nav: float                # 末期单位净值
     annualized_ret: float               # 年化收益
+    cumu_ret: float                     # 累计收益
     annualized_vol: float               # 年化波动率
     sharpe: float                       # 夏普率
+    recent_year_ret: float              # 最近自然年收益
     recent_1m_ret: float                # 最近1月收益
     recent_3m_ret: float                # 最近3月收益
     recent_6m_ret: float                # 最近6月收益
@@ -50,21 +52,38 @@ class SeriesStatUnit:
     downside_std :float                 # 下行风险
     var : float                         # 风险价值VaR
     cvar: float                         # 条件风险价值 CVaR
+    raise_month_num: int                # 上涨月份数
+    drop_month_num: int                 # 下跌月份数
 
 
 @dataclasses.dataclass
 class BenchmarkSeiesStatUnit(SeriesStatUnit):
 
-    alpha: float                # 超额收益
-    beta: float                 # 风险暴露
-    track_err: float            # 跟踪误差
-    ir: float                   # 信息比率
-    alpha_cl: float             # 择股收益
-    beta_cl: float              # 择时收益
-    treynor: float              # 特雷诺
-    win_rate: float             # 胜率
-    win_rate_0: float           # 对零胜率
-    continue_value: float       # 业绩持续性
+    alpha: float                    # 超额收益
+    beta: float                     # 风险暴露
+    track_err: float                # 跟踪误差
+    ir: float                       # 信息比率
+    alpha_cl: float                 # 择股收益
+    beta_cl: float                  # 择时收益
+    treynor: float                  # 特雷诺
+    win_rate: float                 # 对基准胜率
+    win_rate_0: float               # 对零胜率
+    continue_value: float           # 业绩持续性
+    win_rate_weekly: float          # 周度对基准胜率
+    win_rate_0_weekly: float        # 周度对零胜率
+    win_rate_monthly: float         # 月度对基准胜率 
+    win_rate_0_monthly: float       # 月度对零胜率
+    excess_mdd: float               # 超额收益最大回撤
+    excess_mdd_date1: datetime.date # 超额收益最大回撤开始日
+    excess_mdd_date2: datetime.date # 超额收益最大回撤结束日
+    excess_mdd_lens: int            # 超额收益最大回撤持续时间
+    up_capture: float               # 向上捕捉率
+    down_capture: float             # 向下捕捉率
+    not_system_risk: float          # 非系统性风险
+    corr: float                     # 相关性
+    sortino: float                  # 索提诺
+    skew: float                     # 偏度
+    kurtosis: float                 # 峰度
 
 @dataclasses.dataclass
 class RetStatUnit:
@@ -135,6 +154,7 @@ class Calculator:
             annualized_ret=res['annual_ret'],
             annualized_vol=res['annual_vol'],
             sharpe=res['sharpe'],
+            cumu_ret=res['cumu_ret'],
             recent_1m_ret=res['recent_1m_ret'],
             recent_3m_ret=res['recent_3m_ret'],
             recent_6m_ret=res['recent_6m_ret'],
@@ -155,6 +175,9 @@ class Calculator:
             downside_std=res['downside_risk'],
             var=res['var'],
             cvar=res['cvar'],
+            recent_year_ret=res['recent_year_ret'],
+            raise_month_num=res['raise_month_num'],
+            drop_month_num=res['drop_month_num'],
         )
 
     @staticmethod
@@ -223,6 +246,24 @@ class Calculator:
             alpha_cl=res['alpha_cl'],
             beta_cl=res['beta_cl'],
             continue_value=res['continue_value_m'],
+            recent_year_ret=res['recent_year_ret'],
+            raise_month_num=res['raise_month_num'],
+            drop_month_num=res['drop_month_num'],
+            win_rate_weekly=res['win_rate_weekly'],
+            win_rate_0_weekly=res['win_rate_0_weekly'],
+            win_rate_monthly=res['win_rate_monthly'],
+            win_rate_0_monthly=res['win_rate_0_monthly'],
+            excess_mdd=res['excess_mdd'],
+            excess_mdd_date1=res['excess_mdd_date1'],
+            excess_mdd_date2=res['excess_mdd_date2'],
+            excess_mdd_lens=res['excess_mdd_lens'],
+            up_capture=res['up_capture'],
+            down_capture=res['down_capture'],
+            not_system_risk=res['not_system_risk'],
+            corr=res['corr'],
+            sortino=res['sortino'],
+            skew=res['skew'],
+            kurtosis=res['kurtosis'],
         )
 
     @staticmethod
@@ -932,7 +973,7 @@ class Calculator:
     def get_asset_stats(df:pandas.DataFrame, asset_info: pandas.DataFrame):
         real_asset_dic = asset_info.set_index('real_name').to_dict()['asset_type']
         indicator_dics = {
-            'last_unit_nav':'区间收益',
+            'cumu_ret':'区间收益',
             'annualized_ret':'年化收益',
             'annualized_vol':'年化波动',
             'mdd':'最大回撤',
@@ -951,11 +992,12 @@ class Calculator:
 
         df = pandas.DataFrame(result)
         df = df[list(indicator_dics.keys())+['具体指数','类别']].rename(columns=indicator_dics)
-        l = ['夏普比率','具体指数','类别']
+        l = ['夏普比率','具体指数','类别','卡玛比率']
         for col in df:
             if col not in l:
                 df[col] = (df[col] * 100).round(2)
         df['夏普比率'] = df['夏普比率'].round(2)
+        df['卡玛比率'] = df['卡玛比率'].round(2)
         return df
         
     @staticmethod
@@ -982,6 +1024,7 @@ class Calculator:
         df.index.name = 'datetime'
         df = df.pct_change(1).iloc[1:].corr().round(3)
         df = df.sort_values(df.columns[0], ascending=False)
+        df.index.name = 'index_id'
         return df
 
 if __name__ == "__main__":
