@@ -375,6 +375,7 @@ class CalculatorBase:
             annual_vol = sr_ret.std(ddof=1) * np.sqrt(period_1y)
             _begin_date = sr.index[0]
             recent_ret_res = CalculatorBase.calc_recent_ret(dates=dates,values=values,frequency='1D')
+            recent_year_ret = recent_ret_res['recent_natural_year_ret']
             recent_1w_ret = recent_ret_res['recent_1w_ret']
             recent_1m_ret = recent_ret_res['recent_1m_ret']
             recent_3m_ret = recent_ret_res['recent_3m_ret']
@@ -414,7 +415,10 @@ class CalculatorBase:
             ervar = (annual_ret - risk_free_rate) / var
             skew_value = skew(sr_ret)
             kurtosis_value = kurtosis(sr_ret)        
-            
+            sr_ret_monthly = CalculatorBase.data_resample_monthly_ret(sr_ret).dropna()
+            raise_month_num = sr_ret_monthly[sr_ret_monthly>0].shape[0]
+            drop_month_num = sr_ret_monthly[sr_ret_monthly<0].shape[0]
+
             if benchmark_values is not None:
                 assert len(dates) == len(benchmark_values), 'date and bench_values has different numbers'
                 sr_benchmark = pd.Series(benchmark_values, index=dates).sort_index().dropna()
@@ -445,8 +449,16 @@ class CalculatorBase:
                 _index = sorted(sr_ret.index.intersection(sr_benchmark_ret.index))
                 sr_ret = sr_ret.reindex(_index)
                 sr_benchmark_ret = sr_benchmark_ret.reindex(_index)
+                sr_ret_weekly = CalculatorBase.data_resample_weekly_ret(sr_ret).dropna()
+                sr_benchmark_ret_weekly = CalculatorBase.data_resample_weekly_ret(sr_benchmark_ret).dropna()
+                sr_benchmark_ret_monthly = CalculatorBase.data_resample_monthly_ret(sr_benchmark_ret).dropna()
                 win_rate = np.mean((sr_ret > sr_benchmark_ret) * 1)
                 win_rate_0 = np.mean((sr_ret > 0) * 1)
+                win_rate_weekly = np.mean((sr_ret_weekly > sr_benchmark_ret_weekly) * 1)
+                win_rate_0_weekly = np.mean((sr_ret_weekly > 0) * 1)
+                win_rate_monthly = np.mean((sr_ret_monthly > sr_benchmark_ret_monthly) * 1)
+                win_rate_0_monthly = np.mean((sr_ret_monthly > 0) * 1)
+                
                 corr = sr_ret.corr(sr_benchmark_ret)    
                 track_err = (sr_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(period_1y)
                 info = excess_ret / track_err
@@ -507,6 +519,7 @@ class CalculatorBase:
                     'annual_ret':annual_ret,
                     'annual_vol':annual_vol,
                     'sharpe':sharpe,
+                    'recent_year_ret':recent_year_ret,
                     'recent_1w_ret':recent_1w_ret,
                     'recent_1m_ret':recent_1m_ret,
                     'recent_3m_ret':recent_3m_ret,
@@ -541,6 +554,12 @@ class CalculatorBase:
                     'excess_ret':excess_ret,
                     'win_rate':win_rate,
                     'win_rate_0':win_rate_0,
+                    'win_rate_weekly':win_rate_weekly,
+                    'win_rate_0_weekly':win_rate_0_weekly,
+                    'win_rate_monthly':win_rate_monthly,
+                    'win_rate_0_monthly':win_rate_0_monthly,
+                    'raise_month_num':raise_month_num,
+                    'drop_month_num':drop_month_num,
                     'corr':corr,
                     'track_err':track_err,
                     'info':info,
@@ -568,6 +587,7 @@ class CalculatorBase:
                     'annual_ret':annual_ret,
                     'annual_vol':annual_vol,
                     'sharpe':sharpe,
+                    'recent_year_ret':recent_year_ret,
                     'recent_1w_ret':recent_1w_ret,
                     'recent_1m_ret':recent_1m_ret,
                     'recent_3m_ret':recent_3m_ret,
@@ -582,6 +602,8 @@ class CalculatorBase:
                     'recent_drawdown':recent_drawdown,
                     'recent_mdd_date1':recent_mdd_date1,
                     'recent_mdd_lens':recent_mdd_lens,
+                    'raise_month_num':raise_month_num,
+                    'drop_month_num':drop_month_num,
                     'mdd':mdd,
                     'mdd_date1':mdd_date1,
                     'mdd_date2':mdd_date2,
@@ -605,6 +627,7 @@ class CalculatorBase:
                     'annual_ret':0,
                     'annual_vol':0,
                     'sharpe':0,
+                    'recent_year_ret':0,
                     'recent_1w_ret':0,
                     'recent_1m_ret':0,
                     'recent_3m_ret':0,
@@ -640,6 +663,14 @@ class CalculatorBase:
                     'excess_ret':0,
                     'win_rate':0,
                     'win_rate_0':0,
+                    'win_rate_weekly':0,
+                    'win_rate_0_weekly':0,
+                    'win_rate_monthly':0,
+                    'win_rate_0_monthly':0,
+                    'raise_month_num':0,
+                    'drop_month_num':0,
+                    'raise_month_num':0,
+                    'drop_month_num':0,
                     'corr':0,
                     'track_err':0,
                     'info':0,
@@ -816,4 +847,32 @@ class CalculatorBase:
             'rate':rate,
             'limit_num':limit_num,
         }
-        return res
\ No newline at end of file
+        return res
+    
+    @staticmethod
+    def data_resample_monthly_ret(df, rule='1M', min_count=15):
+        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).sum(min_count=min_count)
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        return df
+
+    @staticmethod
+    def data_resample_weekly_ret(df, rule='1W', min_count=3):
+        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).sum(min_count=min_count)
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        return df
+
+    @staticmethod
+    def data_resample_monthly_nav(df, rule='1M'):
+        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).last()
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        return df
+
+    @staticmethod
+    def data_resample_weekly_nav(df, rule='1W'):
+        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).last()
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        return df
