@@ -92,6 +92,19 @@ class WechatBot(object):
             markdown_content += f'\n\n\n>**失效指数({len(indexes_that_become_invalid)}, 请注意处理!!): <font color=\"warning\">{indexes_that_become_invalid}</font>**'
         self.send(markdown_content)
 
+    def send_fund_list_that_set_end_date_failed(self, dt, fund_list: List[str]):
+        markdown_content = f'#### {dt} <font color=\"warning\">设置下列基金摘牌日期失败，请手工修改</font>'
+        markdown_content += f'\n>**{fund_list}**'
+        self.send(markdown_content)
+
+    def send_untreated_new_fund_list(self, dt, fund_list: List[str]):
+        markdown_content = f'#### {dt}'
+        if fund_list:
+            markdown_content += f'\n>**本周累计有下列新基金未处理其 FundInfo & FundBenchmark({len(fund_list)}): <font color=\"warning\">{fund_list}</font>**'
+        else:
+            markdown_content += f'\n><font color=\"info\">本周无未处理其 FundInfo & FundBenchmark 的新基金</font>'
+        self.send(markdown_content)
+
     def send_dump_to_s3_result(self, dt, failed_tables: List[str], failed_dfs: List[str]):
         markdown_content = f'#### {dt}'
         if failed_dfs:
@@ -122,7 +135,7 @@ class WechatBot(object):
         markdown_content += f'\n>**err msg:** {err_msg}'
         self.send(markdown_content)
 
-    def send_hedge_fund_info(self, fof_id: str, fund_id: str, fund_name: str, latest_nav_date: datetime.date, fund_data, holding_data, ret_data_with_last_date):
+    def send_hedge_fund_info(self, fof_id: str, fund_id: str, fund_name: str, latest_nav_date: datetime.date, fund_data, holding_data, ret_data_with_last_date, ret_date_with_last_pub):
         _FUND_DATA_NAME_DICT = {
             'start_date': '成立日期',
             'days': '成立天数',
@@ -151,6 +164,8 @@ class WechatBot(object):
             markdown_content += f'\n><font color=\"info\">{_FUND_DATA_NAME_DICT[k]}: </font>**{v}**'
         if ret_data_with_last_date:
             markdown_content += f'\n><font color=\"info\">相对上一个基准日期({ret_data_with_last_date["date"]})收益率: </font>**{ret_data_with_last_date["rr"]}**'
+        if ret_date_with_last_pub:
+            markdown_content += f'\n><font color=\"info\">相对上一个净值日期({ret_date_with_last_pub["date"]})收益率: </font>**{ret_date_with_last_pub["rr"]}**'
         markdown_content += f'\n>'
         markdown_content += f'\n>**<font color=\"comment\">持仓信息(FOF {fof_id})</font>**'
         for k, v in holding_data.items():
